@@ -22,12 +22,18 @@
 
 """A plugin framework which allows you to write your application as a collection of (optionally interconnected) plugins."""
 
+import os
+from .manager import Manager, run, stop
+
+version_file = os.sep.join([os.path.dirname(os.path.realpath(__file__)), 'version'])
+with open(version_file) as file:
+	version = file.read().strip()
+
 __author__ = "Nick Groenen"
-__version__ = "0.2.3"
+__version__ = version
 __email__ = "zoni@zoni.nl"
 __url__ = "http://octo.zoni.nl"
 
-from .manager import Manager, run, stop
 
 __all__ = ['exceptions', 'manager', 'plugin']
 
